@@ -20,6 +20,9 @@ from zope.interface import implementer, implementer_only
 from pyams_form.browser.textarea import TextAreaWidget
 from pyams_form.interfaces.widget import IFieldWidget, ITextLinesWidget
 from pyams_form.widget import FieldWidget
+from pyams_layer.interfaces import IFormLayer
+from pyams_utils.adapter import adapter_config
+from pyams_utils.schema import ITextLineListField
 
 
 __docformat__ = 'restructuredtext'
@@ -30,7 +33,8 @@ class TextLinesWidget(TextAreaWidget):
     """Input type sequence widget implementation."""
 
 
-@implementer(IFieldWidget)
+@adapter_config(required=(ITextLineListField, IFormLayer),
+                provides=IFieldWidget)
 def TextLinesFieldWidget(field, request):  # pylint: disable=invalid-name
     """IFieldWidget factory for TextLinesWidget."""
     return FieldWidget(field, TextLinesWidget(request))
