@@ -16,6 +16,7 @@ Form related interfaces module.
 """
 
 from zope.interface import Attribute, Interface
+from zope.interface.interfaces import IObjectEvent
 from zope.lifecycleevent import IObjectCreatedEvent
 from zope.schema import ASCIILine, Bool, Choice, Dict, Field, Object, Text, TextLine, Tuple, URI
 
@@ -84,6 +85,8 @@ class IFormAware(Interface):
 class IForm(Interface):
     """Form interface"""
 
+    fields = Attribute("Form fields")
+
     mode = Choice(title=_('Mode'),
                   description=_('The mode in which to render the widgets.'),
                   values=(INPUT_MODE, DISPLAY_MODE),
@@ -376,6 +379,21 @@ class IFormCreatedEvent(IObjectCreatedEvent):
     request = Attribute("Form request")
 
 
+class IFormUpdatedEvent(IObjectEvent):
+    """Form updated event interface"""
+
+    form = Attribute("Form")
+    request = Attribute("Form request")
+
+
+class IFormContent(Interface):
+    """Optional adapter interface used to get form content"""
+
+
+class IFormFields(Interface):
+    """Optional adapter interface used to get form fields"""
+
+
 class IDataExtractedEvent(Interface):
     """Event sent after data and status are extracted from widgets.
     """
